@@ -4,6 +4,8 @@ data loaders (known as Sequence objects in Keras).
 Most users will not need to interact with this module."""
 from abc import abstractmethod
 from operator import itemgetter
+from tensorflow.keras.utils import Sequence
+
 import numpy as np
 from megnet.utils.general import expand_1st, to_list
 from megnet.utils.data import get_graphs_within_cutoff
@@ -11,7 +13,6 @@ from monty.json import MSONable
 from megnet.data import local_env
 from inspect import signature
 from pymatgen.analysis.local_env import NearNeighbors
-from keras.utils import Sequence
 from pymatgen import Structure
 
 from typing import Union, Dict, List, Any
@@ -313,7 +314,7 @@ class MoorseLongRange(Converter):
         r_eq: (list) equilibrium bond length
         p: (int) exponential term in the original equation, see ref
         q: (int) exponential term in the original equaiton, see ref
-        cm: (list) long range coefficients in u_LR = \Sigma_i_N (cm_i / r^i)
+        cm: (list) long range coefficients in u_LR = Sigma_i_N (cm_i / r^i)
         betas: (list) parameters determining the transition between long range and short range
     """
 
@@ -559,7 +560,6 @@ class GraphBatchGenerator(BaseGraphBatchGenerator):
         """
 
         # Get the features and connectivity lists for this batch
-        it = itemgetter(*batch_index)
         feature_list_temp = itemgetter_list(self.atom_features, batch_index)
         connection_list_temp = itemgetter_list(self.bond_features, batch_index)
         global_list_temp = itemgetter_list(self.state_features, batch_index)
