@@ -1,7 +1,14 @@
 from megnet.layers.graph import MEGNetLayer, CrystalGraphLayer, InteractionLayer
 from megnet.layers.readout import Set2Set, LinearWithIndex
-from keras.layers import deserialize as keras_layer_deserialize
+from tensorflow.keras.layers import deserialize as keras_layer_deserialize
 from megnet.losses import mean_squared_error_with_scale
 from megnet.activations import softplus2
 
 _CUSTOM_OBJECTS = globals()
+
+__all__ = [
+    "MEGNetLayer", "CrystalGraphLayer", "InteractionLayer",
+    "Set2Set", "LinearWithIndex",
+    "keras_layer_deserialize", "mean_squared_error_with_scale",
+    "softplus2"
+]
