@@ -1,14 +1,16 @@
 import unittest
-from keras.models import Model
-from keras.layers import Input, Dense
+import numpy as np
+
+from tensorflow.keras.models import Model
+from tensorflow.keras.layers import Input, Dense
 from megnet.callbacks import GeneratorLog, ModelCheckpointMAE, ManualStop, ReduceLRUponNan
 from megnet.layers import MEGNetLayer
 from megnet.utils.preprocessing import StandardScaler
-import numpy as np
+
 import os
 import glob
-import keras.backend as kb
-from keras.utils import Sequence
+import tensorflow.keras.backend as kb
+from tensorflow.keras.utils import Sequence
 from monty.tempfile import ScratchDir
 
 
@@ -18,7 +20,7 @@ class Generator(Sequence):
         self.y = y
 
     def __len__(self):
-        return 10
+        return 1
 
     def __getitem__(self, index):
         return self.x, self.y
@@ -93,13 +95,13 @@ class TestCallBack(unittest.TestCase):
         epoch_count = 0
         for i in range(3):
             if not self.model.stop_training:
-                self.model.fit_generator(self.train_gen, steps_per_epoch=1, epochs=1, callbacks=callbacks, verbose=0)
+                self.model.fit(self.train_gen, steps_per_epoch=1, epochs=1, callbacks=callbacks, verbose=0)
                 epoch_count += 1
         self.assertEqual(epoch_count, 3)
         open('STOP', 'a').close()
         for i in range(3):
             if not self.model.stop_training:
-                self.model.fit_generator(self.train_gen, steps_per_epoch=1, epochs=1, callbacks=callbacks, verbose=0)
+                self.model.fit(self.train_gen, steps_per_epoch=1, epochs=1, callbacks=callbacks, verbose=0)
                 epoch_count += 1
         self.assertEqual(epoch_count, 4)
         os.remove('STOP')
@@ -109,7 +111,7 @@ class TestCallBack(unittest.TestCase):
             callbacks = [ReduceLRUponNan(patience=100)]
             self.assertAlmostEqual(float(kb.get_value(self.model.optimizer.lr)), 1e-3)
             gen = Generator(self.x, np.array([1, np.nan]).reshape((1, 2, 1)))
-            self.model.fit_generator(gen, steps_per_epoch=1, epochs=1, callbacks=callbacks, verbose=0)
+            self.model.fit(gen, steps_per_epoch=1, epochs=1, callbacks=callbacks, verbose=0)
             self.assertAlmostEqual(float(kb.get_value(self.model.optimizer.lr)), 0.5e-3)
 
             inp = [
@@ -121,22 +123,25 @@ class TestCallBack(unittest.TestCase):
                 Input(shape=(None,), dtype='int32'),
                 Input(shape=(None,), dtype='int32'),
             ]
+
             units_v = [2, 2]
             units_e = [2, 2]
             units_u = [2, ]
+
             layer = MEGNetLayer(units_v, units_e, units_u)
             out = layer(inp)
             out = Dense(1)(out[2])
             model = Model(inputs=inp, outputs=out)
             model.compile(loss='mse', optimizer='adam')
+
             x = [np.random.normal(size=(1, 4, self.n_feature)),
-                     np.random.normal(size=(1, 6, self.n_bond_features)),
-                     np.random.normal(size=(1, 2, self.n_global_features)),
-                     np.array([[0, 0, 1, 1, 2, 3]]),
-                     np.array([[1, 1, 0, 0, 3, 2]]),
-                     np.array([[0, 0, 1, 1]]),
-                     np.array([[0, 0, 0, 0, 1, 1]]),
-                     ]
+                 np.random.normal(size=(1, 6, self.n_bond_features)),
+                 np.random.normal(size=(1, 2, self.n_global_features)),
+                 np.array([[0, 0, 1, 1, 2, 3]]),
+                 np.array([[1, 1, 0, 0, 3, 2]]),
+                 np.array([[0, 0, 1, 1]]),
+                 np.array([[0, 0, 0, 0, 1, 1]]),
+                 ]
             y = np.random.normal(size=(1, 2, 1))
             train_gen = Generator(x, y)
 
@@ -145,11 +150,13 @@ class TestCallBack(unittest.TestCase):
                                             steps_per_val=1)
                          ]
             # 1. involve training and saving
-            model.fit_generator(train_gen, steps_per_epoch=1, epochs=2, callbacks=callbacks, verbose=1)
+            model.fit(train_gen, steps_per_epoch=1, epochs=2, callbacks=callbacks, verbose=1)
             # 2. throw nan loss, trigger ReduceLRUponNan
-            model.fit_generator(gen, steps_per_epoch=1, epochs=2, callbacks=callbacks, verbose=1)
+            model.fit(gen, steps_per_epoch=1, epochs=1, callbacks=callbacks, verbose=1)
+            model.fit(gen, steps_per_epoch=1, epochs=1, callbacks=callbacks, verbose=1)
             # 3. Normal training, recover saved model from 1
-            model.fit_generator(train_gen, steps_per_epoch=1, epochs=2, callbacks=callbacks, verbose=1)
+            model.fit(train_gen, steps_per_epoch=1, epochs=2, callbacks=callbacks, verbose=1)
+
             self.assertAlmostEqual(float(kb.get_value(model.optimizer.lr)), 0.25e-3)
 
 
