@@ -1,5 +1,6 @@
 import unittest
 import numpy as np
+
 from megnet.models import MEGNetModel, GraphModel
 from megnet.callbacks import ModelCheckpointMAE, GeneratorLog, ManualStop
 from megnet.data.graph import GaussianDistance
@@ -9,7 +10,7 @@ import os
 from pymatgen import Structure, Lattice
 import shutil
 from monty.tempfile import ScratchDir
-from keras.utils import Sequence
+from tensorflow.keras.utils import Sequence
 from pymatgen.util.testing import PymatgenTest
 
 cwd = os.path.dirname(os.path.abspath(__file__))
